import os
from sidecar.const import Const
from . import ICloudLogger, LogEntry


class FileLogger(ICloudLogger):
    def __init__(self, config: dict):
        apps = config.get("apps")
        for app_name in apps:
            app_folder = Const.get_app_folder(app_name)
            if not os.path.exists(app_folder):
                os.mkdir(app_folder)

    def write(self, log_entry: LogEntry):
        app_folder = Const.get_app_folder(log_entry.app)

        if not os.path.exists("/var/ftp/sandbox/logs"):
            os.makedirs("/var/ftp/sandbox/logs")

        filename = "/var/ftp/sandbox/logs/{0}.{1}-{2}.log".format(log_entry.instance.replace("docker://", ""),
                                                                          log_entry.app, log_entry.log_type)
        lines = ["[{LOG_TYPE}][{TIME}]{LINE}\n".format(LOG_TYPE=log_entry.log_type,
                                                       TIME=time.strftime('%Y-%m-%d %H:%M:%S'),
                                                       LINE=line) for time, line in log_entry.log_events]
        with open(filename, "at") as stream:
            stream.writelines(lines)



from sidecar.const import Const


class KubTokenProvider:
    def get_token(self):
        with open(Const.get_kubernetes_token_file_path(), 'r') as pod_token_file:
            return pod_token_file.read().replace('\n', '')


class FakeKubTokenProvider(KubTokenProvider):
    def get_token(self):
        return "eyJhbGciOiJSUzI1NiIsInR5cCI6IkpXVCJ9.eyJpc3MiOiJrdWJlcm5ldGVzL3NlcnZpY2VhY2NvdW50Iiwia3ViZXJuZXRlcy5pby9zZXJ2aWNlYWNjb3VudC9uYW1lc3BhY2UiOiJrdWJlLXN5c3RlbSIsImt1YmVybmV0ZXMuaW8vc2VydmljZWFjY291bnQvc2VjcmV0Lm5hbWUiOiJuYW1lc3BhY2UtY29udHJvbGxlci10b2tlbi1tcXgxNiIsImt1YmVybmV0ZXMuaW8vc2VydmljZWFjY291bnQvc2VydmljZS1hY2NvdW50Lm5hbWUiOiJuYW1lc3BhY2UtY29udHJvbGxlciIsImt1YmVybmV0ZXMuaW8vc2VydmljZWFjY291bnQvc2VydmljZS1hY2NvdW50LnVpZCI6IjAxODIzOTFlLWJhNjAtMTFlNy1hZTBlLTQyMDEwYThhMDFiMSIsInN1YiI6InN5c3RlbTpzZXJ2aWNlYWNjb3VudDprdWJlLXN5c3RlbTpuYW1lc3BhY2UtY29udHJvbGxlciJ9.xLmVnwnt3gglt15gFS6hUOn3u471tHJjJxj7kHsDVKa-L-iEQAHWJLO2ZNicUMWR_JflEcv8jUB1y6g4vToMlcbQry1C_KLTA_K9fan4uiP60VhqFPM3w9B_0Yk8pI0rrF6adh4LQho6l6LGRTpLoEUOOkCIAxO1HE6DBTujIbjoh2AOSkL02A_rKOuF5X22IaHe9_wdocDnpJOm9q2aldbmHEGlCFVlimpA1vZts8rbVzkajfvGROo_Ug137EEmgYTQxPz2l9o3cr2j9HzuYqMiy_Z_ndOtzEcTohy_HwNv-qdeJliPsCZdSe7Oe3S2LMXoUDH8xaseW5dsLhBRWQ"